@@ -226,7 +226,7 @@ def build(req: dict):
             "make",
             "manifest",
             f"PROFILE={req['profile']}",
-            f"PACKAGES={' '.join(req.get('packages', ''))}",
+            f"PACKAGES={' '.join(sorted(req.get('packages', [])))}",
             "STRIP_ABI=1",
         ],
         text=True,
@@ -294,7 +294,7 @@ def build(req: dict):
         "make",
         "image",
         f"PROFILE={req['profile']}",
-        f"PACKAGES={' '.join(req.get('packages', []))}",
+        f"PACKAGES={' '.join(sorted(req.get('packages', [])))}",
         f"EXTRA_IMAGE_NAME={packages_hash}",
         f"BIN_DIR={req['store_path'] / bin_dir}",
     ]
@@ -327,9 +327,7 @@ def build(req: dict):
     job.save_meta()
 
     if image_build.returncode:
-        job.meta["details"] = "image build error"
-        job.save_meta()
-        return False
+        report_error("Error while building firmware. See stdout/stderr")
 
     if "is too big" in image_build.stderr:
         report_error("Selected packages exceed device storage")
